var group___direct3_d9 =
[
    [ "Ogre::D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html", [
      [ "MultiheadUseType", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652f", [
        [ "mutAuto", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa25921c72928c345bce879cdeb59ea4de", null ],
        [ "mutYes", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652faf9d4681736aed408d4446783840b775f", null ],
        [ "mutNo", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa0e39e4e40a49121c32929470d9829f38", null ]
      ] ],
      [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a14dbc5ade147a1ff11f7f7e2dff70053", null ],
      [ "~D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a5fcc5cf6ff472ea542bb69aeb48b9b01", null ],
      [ "initConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a7c380aa6256e6ad8cd0278cfd4108515", null ],
      [ "getFixedFunctionParams", "class_ogre_1_1_d3_d9_render_system.html#acd1971d83f7000b83eb371d6877d89d2", null ],
      [ "applyFixedFunctionParams", "class_ogre_1_1_d3_d9_render_system.html#a2b34d795def221a7cc257b9d4b8f4589", null ],
      [ "validateConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ac674dcd0e1b47a07723fe341f06eef6d", null ],
      [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#a95b3da61f86ad7af000ca9c971efcdac", null ],
      [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#ad8469f0aa267bf80682e08cdd0a41aaf", null ],
      [ "_createDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#a949fa1062460e37e5a9ca9815486d56d", null ],
      [ "_addManualDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#aa08b2dd098cf209cd3f1102c46cf3c21", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a3c813348d2b65c9bcc7076811c5be436", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#affaba55ebbb835d47398ba424d2191cf", null ],
      [ "_setRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a195727cf757652f7f744a0fa27d19ea8", null ],
      [ "createMultiRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#aa2511e52bd08dced3e30f7002ff67c48", null ],
      [ "detachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a8cc3e0c6a7cad3efc6f8c4e004c9cfa6", null ],
      [ "getErrorDescription", "class_ogre_1_1_d3_d9_render_system.html#aaeb93c2e45c81e44b79eb7c2d37bea84", null ],
      [ "getName", "class_ogre_1_1_d3_d9_render_system.html#a4062d64949c3f8ed6001af07fecca244", null ],
      [ "setConfigOption", "class_ogre_1_1_d3_d9_render_system.html#a1f3c8023280ce8b5915434b2e7f52d20", null ],
      [ "shutdown", "class_ogre_1_1_d3_d9_render_system.html#af14f1a6b539a896178cebfd8a6282fa7", null ],
      [ "setAmbientLight", "class_ogre_1_1_d3_d9_render_system.html#a5c0492ef2b162b8d0297e355c6d93592", null ],
      [ "setShadingType", "class_ogre_1_1_d3_d9_render_system.html#aec34535d0f59c1eb5a2414a210b0a7c3", null ],
      [ "setLightingEnabled", "class_ogre_1_1_d3_d9_render_system.html#adeae40b2bceb2c09b225fec8a80cdfeb", null ],
      [ "destroyRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a13fb04ce75bdf6920f3ce3628a19b610", null ],
      [ "setStencilState", "class_ogre_1_1_d3_d9_render_system.html#a14d7341ecf8e8302da6522a32888203a", null ],
      [ "setNormaliseNormals", "class_ogre_1_1_d3_d9_render_system.html#aec42c90e719c2c1d2581a906e5120ff7", null ],
      [ "_useLights", "class_ogre_1_1_d3_d9_render_system.html#a0c5c4da0ef6d3a0c6185930c1a7dbc44", null ],
      [ "_setSurfaceTracking", "class_ogre_1_1_d3_d9_render_system.html#aa2a9f9542037e5d2afda5d1f744f847d", null ],
      [ "_setPointSpritesEnabled", "class_ogre_1_1_d3_d9_render_system.html#a8087fcbe4777015df90f574b61fdfa67", null ],
      [ "_setPointParameters", "class_ogre_1_1_d3_d9_render_system.html#abf7b4f0bb3c5b3343adc4e76a24cfb35", null ],
      [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d", null ],
      [ "_setSampler", "class_ogre_1_1_d3_d9_render_system.html#a7319688813f35bb96dadbf22075b900b", null ],
      [ "_setTextureCoordSet", "class_ogre_1_1_d3_d9_render_system.html#acfaf7c8ec448362a48a5ab1a026909dd", null ],
      [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d9_render_system.html#aa54b0c2ad942d41897c0b8a0a8e44166", null ],
      [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
      [ "_setTextureMatrix", "class_ogre_1_1_d3_d9_render_system.html#aaf51e7092d88a781953f3d0d0048eb52", null ],
      [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
      [ "_setViewport", "class_ogre_1_1_d3_d9_render_system.html#a85ad53d4f860030b319ce0420f4ece2a", null ],
      [ "_beginFrame", "class_ogre_1_1_d3_d9_render_system.html#a3b458922197e5a3502b29e9bfe016cdf", null ],
      [ "_endFrame", "class_ogre_1_1_d3_d9_render_system.html#aff3564dce1811300a2d4e7a65e4e9c66", null ],
      [ "_setCullingMode", "class_ogre_1_1_d3_d9_render_system.html#a96a7b98979ad56646ad87c4e327098cd", null ],
      [ "_setDepthBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a0d4aad4a09e5ccb9edea8814b53c3142", null ],
      [ "_setDepthBufferCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a28dd997892ac1cb3f0b5f2babfa112d7", null ],
      [ "setColourBlendState", "class_ogre_1_1_d3_d9_render_system.html#a0307e6490c69548914fb9796284d1910", null ],
      [ "_setDepthBufferWriteEnabled", "class_ogre_1_1_d3_d9_render_system.html#aa44f574d9b7aeec5be3b652dbae21d79", null ],
      [ "_setDepthBufferFunction", "class_ogre_1_1_d3_d9_render_system.html#a87d8a1dde9baf36fdc68f5a36c983383", null ],
      [ "_setDepthBias", "class_ogre_1_1_d3_d9_render_system.html#a7830b7940977d3ad920d0984c06113be", null ],
      [ "_setFog", "class_ogre_1_1_d3_d9_render_system.html#a1702436e6653d2102443599326bca7e3", null ],
      [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#acdd1a102566c67c2ce3426f06179cdae", null ],
      [ "_setPolygonMode", "class_ogre_1_1_d3_d9_render_system.html#a0d5d7d3f33d4a8a6ee1ce2e416d7320a", null ],
      [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a014e9b7fe6828806a7234f3115d029b8", null ],
      [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a123832bb34dcbd4c6f25244fa274c103", null ],
      [ "_render", "class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107", null ],
      [ "bindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a82c436739e35880bf9a03d3296b93e4d", null ],
      [ "unbindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a08255da85acf7431528d739c77d37ec3", null ],
      [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d9_render_system.html#ad80a6a285980da1c47bebb4946596039", null ],
      [ "setScissorTest", "class_ogre_1_1_d3_d9_render_system.html#a8d6816d2229a7fc61229e418b9e0ca97", null ],
      [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a6c610caf5ae167ea95b8fa1e59403907", null ],
      [ "setClipPlane", "class_ogre_1_1_d3_d9_render_system.html#a2c6b6c60a60e9bfbf784596e3273e34a", null ],
      [ "enableClipPlane", "class_ogre_1_1_d3_d9_render_system.html#aebb369ceba620861ccd3ff8a1cead931", null ],
      [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#aceacaef86b50bc57a0eed5793ee26e74", null ],
      [ "getHorizontalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#aaa6341e3fe439fffeff5bfffa48ec0e6", null ],
      [ "getVerticalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#a39666e7dd9fc27b22c82b05715fb3ff5", null ],
      [ "getMinimumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#a14c20f8c89b3ef2a8c71daa22f9f02bd", null ],
      [ "getMaximumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#ab55596f38bfc1ba9721eaa121166d7a5", null ],
      [ "IsActiveDeviceLost", "class_ogre_1_1_d3_d9_render_system.html#a683991dc15e1d0c67213b96f9ac7753b", null ],
      [ "isDirectX9Ex", "class_ogre_1_1_d3_d9_render_system.html#a377991202bcd3b2ade63fe13f0540039", null ],
      [ "getResourceManager", "class_ogre_1_1_d3_d9_render_system.html#ac27c2134455ce86c7886c8450a0393ae", null ],
      [ "getDeviceManager", "class_ogre_1_1_d3_d9_render_system.html#afaf9cf2f1d9cd94d8be47d9047533544", null ],
      [ "getDirect3D9", "class_ogre_1_1_d3_d9_render_system.html#a62aa32d65cc848c3149767be38e0c244", null ],
      [ "getResourceCreationDeviceCount", "class_ogre_1_1_d3_d9_render_system.html#af9b728ddf675afcecfafd0d4d335c63c", null ],
      [ "getResourceCreationDevice", "class_ogre_1_1_d3_d9_render_system.html#ad177ce11d6941a706429db4a973faad4", null ],
      [ "getActiveD3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a73585609cd73845b9217349725ca278b", null ],
      [ "getActiveD3D9DeviceIfExists", "class_ogre_1_1_d3_d9_render_system.html#a14902091a74d2a3799b2929f11b2dabe", null ],
      [ "getAdapterNumber", "class_ogre_1_1_d3_d9_render_system.html#af25d5322ec044e06b143cc04a0f37bcb", null ],
      [ "_getDepthStencilFormatFor", "class_ogre_1_1_d3_d9_render_system.html#a756e9227a2d0147e31100ce041d4f9cb", null ],
      [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d9_render_system.html#a09b739bb7b2d3c3aff1fecece56e9baa", null ],
      [ "determineFSAASettings", "class_ogre_1_1_d3_d9_render_system.html#abeb5bc1a5691a572c5dc2f4775cf76c5", null ],
      [ "beginProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b", null ],
      [ "endProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7", null ],
      [ "markProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#a489d99fe770e4c105434ed13911ce350", null ],
      [ "fireDeviceEvent", "class_ogre_1_1_d3_d9_render_system.html#ace53b06d3e61511f9b2dc6156e31c9a9", null ],
      [ "getMultiheadUse", "class_ogre_1_1_d3_d9_render_system.html#a7f5e2beb4bd0d894ee99c6468ba20ee7", null ],
      [ "setDrawBuffer", "class_ogre_1_1_d3_d9_render_system.html#a869123f35563093de0f4fe68321b9b4b", null ],
      [ "createStereoDriver", "class_ogre_1_1_d3_d9_render_system.html#a296a4b8cb73c61dced451b6e23e95919", null ],
      [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
      [ "D3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a62a49b9f66b36b9be215f88e190366a2", null ],
      [ "D3D9DeviceManager", "class_ogre_1_1_d3_d9_render_system.html#aec82c6ec0be39f7ecb3e0d165125a540", null ]
    ] ]
];